# Trading game for recruitment events. 

## Usage

`pip install gr-tradinggame`

### Manual game

1. Run the code in `manual/example.py` in a notebook (looks best on Colab, with fullscreen cell display). 
2. Have teams shout / show their decisions and enter them by clicking buttons. 

### Coding game

1. Run the code in `coding/example_server.py`. 
2. The output will contain `Serving <id>`. Give that `id` to the teams and have them test and submit their solutions with that `id` as in `coding/example_client.py`. 
3. Run the code in `coding/example_gui.py` to see who wins.
